# eric7.WebBrowser.QtHelp.HelpSearchWidget

Module implementing a window for showing the QtHelp index.

### Global Attributes

None

### Classes

HelpSearchWidget | Class implementing a window for showing the QtHelp index.

### Functions

None

## HelpSearchWidget

Class implementing a window for showing the QtHelp index.

### Signals

escapePressed()
  emitted when the ESC key was pressed
newBackgroundTab(QUrl, str)
  emitted to open a search result entry in a new background tab
newTab(QUrl, str)
  emitted to open a search result entry in a new tab
newWindow(QUrl, str)
  emitted to open a search result entry in a new window
openUrl(QUrl, str)
  emitted to open a search result entry in the current tab

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

HelpSearchWidget | Constructor
__linkActivated | Private slot handling the activation of an entry.
__search | Private slot to perform a search of the database.
__searchingFinished | Private slot to handle the end of the search.
__searchingStarted | Private slot to handle the start of a search.
contextMenuEvent | Protected method handling context menu events.
keyPressEvent | Protected method handling key press events.

### Static Methods

None

#### HelpSearchWidget (Constructor)

HelpSearchWidget(engine, internal=False, parent=None)

Constructor

engine (QHelpSearchEngine)
  reference to the help search engine
internal (bool)
  flag indicating the internal help viewer
parent (QWidget)
  reference to the parent widget

#### HelpSearchWidget.__linkActivated

__linkActivated(url)

Private slot handling the activation of an entry.

url (QUrl)
  URL of the activated entry

#### HelpSearchWidget.__search

__search()

Private slot to perform a search of the database.

#### HelpSearchWidget.__searchingFinished

__searchingFinished(hits)

Private slot to handle the end of the search.

hits (int)
  number of hits (unused)

#### HelpSearchWidget.__searchingStarted

__searchingStarted()

Private slot to handle the start of a search.

#### HelpSearchWidget.contextMenuEvent

contextMenuEvent(evt)

Protected method handling context menu events.

evt
  reference to the context menu event (QContextMenuEvent)

#### HelpSearchWidget.keyPressEvent

keyPressEvent(evt)

Protected method handling key press events.

evt (QKeyEvent)
  reference to the key press event

Up